@@ -1,8 +1,9 @@
 /* Traitement de certaines tables africaines.
-   Copyright  1999, 2000 Progiciels Bourbeau-Pinard inc.
-   Franois Pinard <pinard@iro.umontreal.ca>, 1997.  */
+   Copyright © 1999, 2000 Progiciels Bourbeau-Pinard inc.
+   François Pinard <pinard@iro.umontreal.ca>, 1997.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 /* Bambara, Ewondo and Fulfude.  */
 
@@ -107,31 +108,19 @@ static const unsigned short lin_data[] =
 bool
 module_african (RECODE_OUTER outer)
 {
-  if (!declare_explode_data (outer, ful_data, "AFRFUL-102-BPI_OCIL", NULL))
-    return false;
-  if (!declare_alias (outer, "bambara", "AFRFUL-102-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "bra", "AFRFUL-102-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "ewondo", "AFRFUL-102-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "fulfulde", "AFRFUL-102-BPI_OCIL"))
-    return false;
-  if (!declare_explode_data (outer, lin_data, "AFRLIN-104-BPI_OCIL", NULL))
-    return false;
-  if (!declare_alias (outer, "lingala", "AFRLIN-104-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "lin", "AFRLIN-104-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "sango", "AFRLIN-104-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "wolof", "AFRLIN-104-BPI_OCIL"))
-    return false;
-
-  return true;
+  return declare_explode_data (outer, ful_data, "AFRFUL-102-BPI_OCIL", NULL)
+    && declare_alias (outer, "bambara", "AFRFUL-102-BPI_OCIL")
+    && declare_alias (outer, "bra", "AFRFUL-102-BPI_OCIL")
+    && declare_alias (outer, "ewondo", "AFRFUL-102-BPI_OCIL")
+    && declare_alias (outer, "fulfulde", "AFRFUL-102-BPI_OCIL")
+    && declare_explode_data (outer, lin_data, "AFRLIN-104-BPI_OCIL", NULL)
+    && declare_alias (outer, "lingala", "AFRLIN-104-BPI_OCIL")
+    && declare_alias (outer, "lin", "AFRLIN-104-BPI_OCIL")
+    && declare_alias (outer, "sango", "AFRLIN-104-BPI_OCIL")
+    && declare_alias (outer, "wolof", "AFRLIN-104-BPI_OCIL");
 }
 
-void
-delmodule_african (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_african (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
